#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# (c) 2010 by Ingo Weinzierl <ingo.weinzierl@intevation.de>
# (c) 2011 by Björn Ricks <bjoern.ricks@intevation.de>
#
# A python worklog-alike to log what you have 'getan' (done).
#
# This is Free Software licensed under the terms of GPLv3 or later.
# For details see LICENSE coming with the source of 'getan'.
#

import logging
import os
import os.path
import argparse

import getan
import getan.config as config

from getan.backend import DEFAULT_DATABASE, Backend
from getan.controller import GetanController

logger = logging.getLogger()


def main():

    usage = "%(prog)s [options] [databasefile (default: " + \
        DEFAULT_DATABASE + ")]"
    version = "getan version %s" % getan.__version__

    parser = argparse.ArgumentParser(prog='getan', usage=usage)
    parser.add_argument('--version', action='version', version=version)
    parser.add_argument(dest='filename', nargs='?',
                        help='[databasefile (default: time.db)]')
    parser.add_argument('--init-only', action='store_true', dest='initonly',
                        help='create databasefile if necessary and exit')
    parser.add_argument('-d', '--debug', action='store_true', dest='debug',
                        help='set verbosity to debug')
    # Default value of the logfile name is defined in .getan/config.py.
    parser.add_argument('-l', '--logfile', dest='logfile', metavar='FILE',
                    help='write log information to FILE [default: getan.log]',
                        nargs='?')

    args = parser.parse_args()

    logargs = dict()

    if args.debug:
        logargs["level"] = logging.DEBUG
    if args.logfile:
        logargs["filename"] = args.logfile
    config.initialize(**logargs)
    global logger

    if args.filename != None :
        backend = Backend(args.filename)
        logging.info("Using database '%s'." % args.filename)
    else:
        if os.path.isfile(DEFAULT_DATABASE):
            database = os.path.abspath(DEFAULT_DATABASE)
        else:
            getan_dir = os.path.expanduser(os.path.join("~", ".getan"))
            if not os.path.exists(getan_dir):
                os.mkdir(getan_dir)
            database = os.path.join(getan_dir, DEFAULT_DATABASE)

        backend = Backend(database)
        logging.info("Using database '%s'." % database)

    if args.initonly:
        return

    controller = GetanController(backend)

    try:
        controller.main()
    except KeyboardInterrupt:
        pass
    finally:
        controller.shutdown()


if __name__ == '__main__':
    main()
